@@ -4,10 +4,11 @@ pub use crate::balance::Balance;
 pub use crate::coin::{Cw20Coin, Cw20CoinVerified};
 pub use crate::denom::Denom;
 pub use crate::helpers::Cw20Contract;
+pub use crate::logo::{EmbeddedLogo, Logo, LogoInfo};
 pub use crate::msg::Cw20ExecuteMsg;
 pub use crate::query::{
     AllAccountsResponse, AllAllowancesResponse, AllowanceInfo, AllowanceResponse, BalanceResponse,
-    Cw20QueryMsg, MinterResponse, TokenInfoResponse,
+    Cw20QueryMsg, DownloadLogoResponse, MarketingInfoResponse, MinterResponse, TokenInfoResponse,
 };
 pub use crate::receiver::Cw20ReceiveMsg;
 
@@ -15,6 +16,7 @@ mod balance;
 mod coin;
 mod denom;
 mod helpers;
+mod logo;
 mod msg;
 mod query;
 mod receiver;
